Introduction
============

django-comments-dab App - v1.1.0
--------------------------------

**dab stands for Django-Ajax-Bootstrap**

``django-comments-dab`` is a commenting application for Django-powered
websites.

It allows you to integrate commenting functionality to any model you
have e.g. blogs, pictures, etc…

*List of actions you can do:*

    1. Add a comment. (Authenticated)

    2. Edit a comment you posted. (Authenticated)

    3. Delete a comment you posted. (Authenticated)


**-All actions are done by ajax - JQuery 3.2.1**

**-Bootstrap 4.1.1 is used in comment templates for responsive design.**
